@@ -28,6 +28,8 @@ class RegisteredBindingMetaClass(type):
             binding_class._lazy_bindings_by_stream = registered_lazy_binding_by_stream
             binding_class._lazy_bindings_by_stream[stream] = binding_class._lazy
             binding_class.connect_signals()
+            if binding_class.model:
+                binding_class.model._last_binding_stream = stream
 
             for method_name in dir(binding_class):
                 method = getattr(binding_class, method_name)
