@@ -7,7 +7,7 @@ from django.utils.module_loading import import_string
 
 DJANGO_ALLOW_ASYNC_UNSAFE = os.environ.get('DJANGO_ALLOW_ASYNC_UNSAFE')
 if DJANGO_ALLOW_ASYNC_UNSAFE != "true":
-    print('Automatic turns environ DJANGO_ALLOW_ASYNC_UNSAFE variable to "true"')
+    print('------- Automatic turns environ DJANGO_ALLOW_ASYNC_UNSAFE variable to "true" -------')
     os.environ["DJANGO_ALLOW_ASYNC_UNSAFE"] = "true"
 
 CHANNELS_BINDING = getattr(settings, 'CHANNELS_BINDING', {})
